@@ -15,11 +15,14 @@ class Command(BaseCommand):
     help = 'Cleans up old entries in the log.'
 
     def handle(self, *args, **options):
-        ts = datetime.datetime.now() - datetime.timedelta(days=options.get('days', 30))
+        days = 30
+        if options.get('days'): # options always contain the days key
+            days = int(options['days'])
+        ts = datetime.datetime.now() - datetime.timedelta(days=days)
         
         base_kwargs = {}
         if options.get('logger'):
             base_kwargs['logger'] = options['logger']
         
         GroupedMessage.objects.filter(last_seen__lte=ts, **base_kwargs).delete()
-        Message.objects.filter(datetime__lte=ts, **base_kwargs).delete()
\ No newline at end of file
+        Message.objects.filter(datetime__lte=ts, **base_kwargs).delete()
