@@ -19,6 +19,7 @@ from django.core.signals import got_request_exception
 from django.core.servers import basehttp
 from django.test.client import Client
 from django.test import TestCase
+from django.template import TemplateSyntaxError
 from django.utils.encoding import smart_unicode
 from django.utils import simplejson
 
@@ -546,6 +547,24 @@ class SentryTestCase(TestCase):
 
         self.assertEquals(GroupedMessage.objects.count(), 1)
 
+    def testIncludeModules(self):
+        settings.INCLUDE_PATHS = ['django.shortcuts.get_object_or_404']
+        
+        self.assertRaises(Exception, self.client.get, reverse('sentry-django-exc'))
+        
+        last = Message.objects.get()
+        
+        self.assertEquals(last.view, 'django.shortcuts.get_object_or_404')
+        
+        settings.INCLUDE_PATHS = []
+
+    def testTemplateNameAsView(self):
+        self.assertRaises(TemplateSyntaxError, self.client.get, reverse('sentry-template-exc'))
+        
+        last = Message.objects.get()
+        
+        self.assertEquals(last.view, 'sentry-tests/error.html')
+
 class SentryViewsTest(TestCase):
     urls = 'sentry.tests.urls'
     fixtures = ['sentry/tests/fixtures/views.json']
